@@ -11,7 +11,7 @@ import pickle
 import tempfile
 import os
 import numpy as np
-from PyFin.Analysis.SecurityValues import SecurityValues
+from PyFin.Analysis.SeriesValues import SeriesValues
 
 
 class TestSecurityValues(unittest.TestCase):
@@ -20,7 +20,7 @@ class TestSecurityValues(unittest.TestCase):
         data = np.array([1, 2, 3])
         index = ['c', 'b', 'a']
 
-        test = SecurityValues(data, dict(zip(index, range(len(index)))))
+        test = SeriesValues(data, dict(zip(index, range(len(index)))))
         expected = dict(zip(index, data))
 
         for name in test.index():
@@ -31,10 +31,23 @@ class TestSecurityValues(unittest.TestCase):
         data = np.array([3, 2, np.nan, np.nan, 4, 5])
         index = [1, 2, 3, 4, 5, 6]
 
-        data = SecurityValues(data, dict(zip(index, range(len(index)))))
+        data = SeriesValues(data, index)
         test = data.rank()
 
-        expected = SecurityValues(np.array([2, 1, np.nan, np.nan, 3, 4]), dict(zip(index, range(len(index)))))
+        expected = SeriesValues(np.array([2, 1, np.nan, np.nan, 3, 4]), dict(zip(index, range(len(index)))))
+        for name in test.index():
+            if np.isnan(test[name]):
+                self.assertTrue(np.isnan(expected[name]))
+            else:
+                self.assertEqual(test[name], expected[name])
+
+    def testSecurityValuesUnit(self):
+        data = np.array([3, -2, np.nan, np.nan, 4, 5])
+        index = [1, 2, 3, 4, 5, 6]
+        test = SeriesValues(data, index)
+        test = test.unit()
+
+        expected = SeriesValues(data / np.nansum(np.abs(data)), dict(zip(index, range(len(index)))))
         for name in test.index():
             if np.isnan(test[name]):
                 self.assertTrue(np.isnan(expected[name]))
@@ -45,7 +58,7 @@ class TestSecurityValues(unittest.TestCase):
         data = np.array([3, 2, 2., 1., 4., 5.])
         index = [1, 2, 3, 4, 5, 6]
 
-        test = SecurityValues(data, dict(zip(index, range(len(index)))))
+        test = SeriesValues(data, index)
         copied = copy.deepcopy(test)
 
         np.testing.assert_array_equal(test.values, copied.values)
@@ -57,23 +70,23 @@ class TestSecurityValues(unittest.TestCase):
         data2 = -np.array([3, 2, 2., 1., 4., 5.])
         index = [1, 2, 3, 4, 5, 6]
 
-        test1 = SecurityValues(data1, dict(zip(index, range(len(index)))))
-        test2 = SecurityValues(data2, dict(zip(index, range(len(index)))))
+        test1 = SeriesValues(data1, index)
+        test2 = SeriesValues(data2, index)
 
         calculated = test1 + test2
-        expected = SecurityValues(data1 + data2, dict(zip(index, range(len(index)))))
+        expected = SeriesValues(data1 + data2, index)
 
         np.testing.assert_array_equal(calculated.values, expected.values)
         self.assertEqual(calculated.name_mapping, expected.name_mapping)
 
         calculated = test1 + 2.0
-        expected = SecurityValues(data1 + 2.0, dict(zip(index, range(len(index)))))
+        expected = SeriesValues(data1 + 2.0, index)
 
         np.testing.assert_array_equal(calculated.values, expected.values)
         self.assertEqual(calculated.name_mapping, expected.name_mapping)
 
         calculated = 2.0 + test2
-        expected = SecurityValues(2.0 + data2, dict(zip(index, range(len(index)))))
+        expected = SeriesValues(2.0 + data2, index)
 
         np.testing.assert_array_equal(calculated.values, expected.values)
         self.assertEqual(calculated.name_mapping, expected.name_mapping)
@@ -84,23 +97,23 @@ class TestSecurityValues(unittest.TestCase):
         data2 = -np.array([3, 2, 2., 1., 4., 5.])
         index = [1, 2, 3, 4, 5, 6]
 
-        test1 = SecurityValues(data1, dict(zip(index, range(len(index)))))
-        test2 = SecurityValues(data2, dict(zip(index, range(len(index)))))
+        test1 = SeriesValues(data1, index)
+        test2 = SeriesValues(data2, index)
 
         calculated = test1 - test2
-        expected = SecurityValues(data1 - data2, dict(zip(index, range(len(index)))))
+        expected = SeriesValues(data1 - data2, index)
 
         np.testing.assert_array_equal(calculated.values, expected.values)
         self.assertEqual(calculated.name_mapping, expected.name_mapping)
 
         calculated = test1 - 2.0
-        expected = SecurityValues(data1 - 2.0, dict(zip(index, range(len(index)))))
+        expected = SeriesValues(data1 - 2.0, index)
 
         np.testing.assert_array_equal(calculated.values, expected.values)
         self.assertEqual(calculated.name_mapping, expected.name_mapping)
 
         calculated = 2.0 - test2
-        expected = SecurityValues(2.0 - data2, dict(zip(index, range(len(index)))))
+        expected = SeriesValues(2.0 - data2, index)
 
         np.testing.assert_array_equal(calculated.values, expected.values)
         self.assertEqual(calculated.name_mapping, expected.name_mapping)
@@ -111,23 +124,23 @@ class TestSecurityValues(unittest.TestCase):
         data2 = -np.array([3, 2, 2., 1., 4., 5.])
         index = [1, 2, 3, 4, 5, 6]
 
-        test1 = SecurityValues(data1, dict(zip(index, range(len(index)))))
-        test2 = SecurityValues(data2, dict(zip(index, range(len(index)))))
+        test1 = SeriesValues(data1, index)
+        test2 = SeriesValues(data2, index)
 
         calculated = test1 * test2
-        expected = SecurityValues(data1 * data2, dict(zip(index, range(len(index)))))
+        expected = SeriesValues(data1 * data2, index)
 
         np.testing.assert_array_equal(calculated.values, expected.values)
         self.assertEqual(calculated.name_mapping, expected.name_mapping)
 
         calculated = test1 * 2.0
-        expected = SecurityValues(data1 * 2.0, dict(zip(index, range(len(index)))))
+        expected = SeriesValues(data1 * 2.0, index)
 
         np.testing.assert_array_equal(calculated.values, expected.values)
         self.assertEqual(calculated.name_mapping, expected.name_mapping)
 
         calculated = 2.0 * test2
-        expected = SecurityValues(2.0 * data2, dict(zip(index, range(len(index)))))
+        expected = SeriesValues(2.0 * data2, index)
 
         np.testing.assert_array_equal(calculated.values, expected.values)
         self.assertEqual(calculated.name_mapping, expected.name_mapping)
@@ -138,23 +151,23 @@ class TestSecurityValues(unittest.TestCase):
         data2 = -np.array([3, 2, 2., 1., 4., 5.])
         index = [1, 2, 3, 4, 5, 6]
 
-        test1 = SecurityValues(data1, dict(zip(index, range(len(index)))))
-        test2 = SecurityValues(data2, dict(zip(index, range(len(index)))))
+        test1 = SeriesValues(data1, index)
+        test2 = SeriesValues(data2, index)
 
         calculated = test1 / test2
-        expected = SecurityValues(data1 / data2, dict(zip(index, range(len(index)))))
+        expected = SeriesValues(data1 / data2, index)
 
         np.testing.assert_array_equal(calculated.values, expected.values)
         self.assertEqual(calculated.name_mapping, expected.name_mapping)
 
         calculated = test1 / 2.0
-        expected = SecurityValues(data1 / 2.0, dict(zip(index, range(len(index)))))
+        expected = SeriesValues(data1 / 2.0, index)
 
         np.testing.assert_array_equal(calculated.values, expected.values)
         self.assertEqual(calculated.name_mapping, expected.name_mapping)
 
         calculated = 2.0 / test2
-        expected = SecurityValues(2.0 / data2, dict(zip(index, range(len(index)))))
+        expected = SeriesValues(2.0 / data2, index)
 
         np.testing.assert_array_equal(calculated.values, expected.values)
         self.assertEqual(calculated.name_mapping, expected.name_mapping)
@@ -163,7 +176,7 @@ class TestSecurityValues(unittest.TestCase):
         data = np.array([3, 2, np.nan, np.nan, 4, 5])
         index = [1, 2, 3, 4, 5, 6]
 
-        test = SecurityValues(data, dict(zip(index, range(len(index)))))
+        test = SeriesValues(data, index)
 
         f = tempfile.NamedTemporaryFile('w+b', delete=False)
         pickle.dump(test, f)
